package jp.ameba.sp.app.controller 
{
	
	import flash.display.*;
	import flash.events.*;
	import flash.sensors.*;
	import flash.text.*;
	import flash.utils.*;
	import jp.ameba.sp.app.SampleMain;
	
	/**
	 * 加速度センサーを操作するクラス.
	 * このクラスのstartUpAccelerometer()を呼び出すと
	 * 画面上にキャラが登場してデバイスを傾けた向きに動いて行きます.
	 */
	public class AccelerometerController
	{
		private var _main:SampleMain;
		
		/*加速度センターで使うボールのMovieClip.*/
		var _myChara:MovieClip;
		/*加速度センサークラス.*/
		var _myAccelerometer:Accelerometer;
		/*X方向の速度.*/
		var _speedX:Number = 0;
		/*Y方向の速度.*/
		var _speedY:Number = 0;
		
		
		
		/**
		 * コンストラクタ.
		 */
		public function AccelerometerController()
		{
			_main = SampleMain.getInstance();
		}
		
		/**
		 * 加速度センサーの準備をする.
		 */
		public function startUp() {
			// ボールのインスタンスを作成
			var ballClass:Class = Class(getDefinitionByName("chara"));
			_myChara = new ballClass() as MovieClip;
			
			// 画面に配置する
			_main.getStage().addChild(_myChara);
			_myChara.x = _main.getStage().stageWidth/2;
			_myChara.y = _myChara.height/2;
			// backボタンに終了時に実行するfunctionの参照を渡す
			_main.setBackBtnAction(backBtnHandler);
			// 加速度イベントを設定
			_myAccelerometer = new Accelerometer();
			// MovieClip等ではなくAccelerometerのインスタンスにイベントを設定する
			_myAccelerometer.addEventListener(AccelerometerEvent.UPDATE, accelHandler);
		}
		
		/**
		 * 加速度センサーの値が更新された時の処理.
		 * @param evt
		 * @return 
		 * 
		 */
		function accelHandler(evt:AccelerometerEvent) {
			// スピードの加速度センサーの値を足していく
			_speedX += evt.accelerationX;
			_speedY += evt.accelerationY;
			
			// 設定した速度でボールを動かす
			_myChara.x -= _speedX;
			_myChara.y += _speedY;
			
			// 画面端にきた時の処理
			// 画面端に位置を戻して速度をリセットします
			if (_myChara.x < 0+_myChara.width/2) {
				_myChara.x = _myChara.width/2;
				_speedX = 0;
				_speedY = 0;
			}
			if (_myChara.x > _main.getStage().stageWidth-_myChara.width/2) {
				_myChara.x = _main.getStage().stageWidth - _myChara.width/2;
				_speedX = 0;
				_speedY = 0;
			}
			if (_myChara.y < 0+_myChara.height/2) {
				_myChara.y = _myChara.height/2;
				_speedX = 0;
				_speedY = 0;
			}
			if (_myChara.y > _main.getStage().stageHeight- _myChara.height/2) {
				_myChara.y = _main.getStage().stageHeight - _myChara.height/2;
				_speedX = 0;
				_speedY = 0;
			}
		}
		/**
		 * 加速度センサーを終了する.
		 * (backボタン用)
		 * @param evt マウスイベント
		 */
		public function backBtnHandler(evt:MouseEvent) {
			endAccel();
		}
		/**
		 * 加速度センサーを終了する.
		 */
		function endAccel() {
			_myAccelerometer.removeEventListener(AccelerometerEvent.UPDATE, accelHandler);
			_main.getStage().removeChild(_myChara);
			_main.backBtnAction();
		}
	}
}