package jp.ameba.sp.app.controller   {
	import flash.display.*;
	import flash.events.*;
	import flash.filesystem.*;
	import flash.media.*;
	
	import jp.ameba.sp.app.SampleMain;
	
	/** 
	 * デバイスのカメラを起動するクラス.
	 * このクラスのstartUpCamera()を呼び出すと
	 * デバイスに搭載されているカメラを起動します.
	 */
	public class CameraController
	{
		/*デバイスカメラ.*/
		private var _myCameraUI:CameraUI;
		
		/*画像のローダー.*/
		private var _imageLoader:Loader;
		/*メインクラス.*/
		private var _main:SampleMain;
		
		/**
		 * コンストラクタ.
		 * カメラ機能が搭載されているかをチェックする.
		 */
		public function CameraController()
		{
			_main = SampleMain.getInstance();
		}
		
		/**
		 * カメラを起動する.
		 */
		public function startUp() {
			// カメラUIを初期化
			_myCameraUI = new CameraUI();
			// カメラモードを画像に設定.動画の場合は"MediaType.VIDEO"を指定します
			_myCameraUI.launch(MediaType.IMAGE);
			// 画像処理の完了イベントを設定
			_myCameraUI.addEventListener(MediaEvent.COMPLETE, this.takePictureHandler);
			// 写真を撮らずにキャンセルした場合のイベントを設定
			_myCameraUI.addEventListener(Event.CANCEL, this.cancelHandler);
		}
		/**
		 * カメラをキャンセルした場合の処理.
		 * @param evt キャンセル
		 */
		function cancelHandler(evt:Event) {
			_main.showButtons();
		}
		/**
		 * 写真を撮影した後に呼び出されます.
		 * 撮影した写真に加工を加えたい場合はここから始めます.
		 * @param evt MedeaEvent.この中には撮影データへの参照などが含まれます.
		 */
		function takePictureHandler(evt:MediaEvent) {
			// loadingをくっつける
			_main.addLoading();
			
			// 画像にアクセスすることを許可するクラスです
			var mediaPromise:MediaPromise = evt.data as MediaPromise;
			
			// 撮影した画像を直接編集したい場合はこの後に処理を書きます
			_imageLoader = new Loader();
			_imageLoader.loadFilePromise( mediaPromise );
			_imageLoader.contentLoaderInfo.addEventListener(Event.COMPLETE, showPhoto);
		}
		/**
		 * 選択した写真の読み込みが完了すると呼び出されます.
		 * 画面のサイズと設定した余白に合わせて画像の大きさや位置を修正します.
		 * @param evt 画像読み込み完了のイベント
		 */
		function showPhoto(evt:Event) {
			_main.removeLoading();
			// 画面へ登録
			_main.getStage().addChild(_imageLoader);
			// 画面との比率計算
			var ratioX:Number  = (_main.getStage().stageWidth-SampleMain.MARGIN_LEFT) / _imageLoader.width;
			var ratioY:Number = (_main.getStage().stageHeight-SampleMain.MARGIN_TOP) / _imageLoader.height;
			if (ratioX > ratioY) {
				// 幅のほうが小さい場合は高さを幅に合わせる
				_imageLoader.width = _main.getStage().stageWidth;
				_imageLoader.height *= ratioX;
			}
			else {
				_imageLoader.height = _main.getStage().stageHeight;
				_imageLoader.width *= ratioY;
			}
			// 中央にセット
			_imageLoader.x = (_main.getStage().stageWidth -SampleMain.MARGIN_LEFT - _imageLoader.width)/2;
			_imageLoader.y = (_main.getStage().stageHeight -SampleMain.MARGIN_TOP - _imageLoader.height)/2;
			
			// 戻るボタンを配置する
			_main.setBackBtnAction(this.backBtnHandler);
		}
		
		/**
		 * 写真の表示から戻る.
		 * @param evt クリックイベント
		 */
		public function backBtnHandler(evt:MouseEvent) {
			_main.getStage().removeChild(_imageLoader);
			_main.backBtnAction();
		}
	}
}