package jp.ameba.sp.app.controller
{
	import flash.display.*;
	import flash.events.*;
	import flash.filesystem.*;
	import flash.media.*;
	import flash.system.*;
	import flash.text.*;
	import flash.utils.*;
	
	import jp.ameba.sp.app.SampleMain;
	
	/**
	 * カメラロールへアクセスするクラスです.
	 * 選択した画像を画面に表示します.
	 */
	public class CameraRollController
	{
		/*メインクラスへの参照.*/
		private var _main:SampleMain;
		/*カメラロールクラス.*/
		private var _myCameraRoll:CameraRoll;
		
		/*画像のローダー.*/
		private var _imageLoader:Loader;
		
		/**
		 * コンストラクタ.
		 */
		public function CameraRollController()
		{
			_main = SampleMain.getInstance();
		}
		
		/**
		 * カメラロールを開きます.
		 */
		public function startUp() {
			// カメラロールクラスのインスタンスを作成
			_myCameraRoll = new CameraRoll();
			// 写真を選択した時のイベント
			_myCameraRoll.addEventListener(MediaEvent.SELECT, this.imageSelectedHandler);
			// カメラロールをキャンセルした時のイベント
			_myCameraRoll.addEventListener(Event.CANCEL, this.cancelHandler);
			// カメラロールを開く
			_myCameraRoll.browseForImage();
		}
		
		/**
		 * 写真を選択すると呼び出されます.
		 * 選択した写真を画面に表示する準備をします.
		 * @param evt 写真選択のイベント
		 */
		function imageSelectedHandler(evt:MediaEvent) {
			// loadingをくっつける
			_main.addLoading();
			
			var mediaPromise:MediaPromise = evt.data as MediaPromise;
			_imageLoader = new Loader();
			_imageLoader.loadFilePromise( mediaPromise );
			_imageLoader.contentLoaderInfo.addEventListener(Event.COMPLETE, showPhoto);
			
		}
		
		
		/**
		 * 選択した写真の読み込みが完了すると呼び出されます.
		 * 画面のサイズと設定した余白に合わせて画像の大きさや位置を修正します.
		 * @param evt 画像読み込み完了のイベント
		 */
		function showPhoto(evt:Event) {
			_main.removeLoading();
			
			// 画面へ登録
			_main.getStage().addChild(_imageLoader);
			// 画面との比率計算
			var ratioX:Number  = (_main.getStage().stageWidth-SampleMain.MARGIN_LEFT) / _imageLoader.width;
			var ratioY:Number = (_main.getStage().stageHeight-SampleMain.MARGIN_TOP) / _imageLoader.height;
			if (ratioX > ratioY) {
				// 幅のほうが小さい場合は高さを幅に合わせる
				_imageLoader.width = _main.getStage().stageWidth;
				_imageLoader.height *= ratioX;
			}
			else {
				_imageLoader.height = _main.getStage().stageHeight;
				_imageLoader.width *= ratioY;
			}
			// 中央にセット
			_imageLoader.x = (_main.getStage().stageWidth -SampleMain.MARGIN_LEFT - _imageLoader.width)/2;
			_imageLoader.y = (_main.getStage().stageHeight -SampleMain.MARGIN_TOP - _imageLoader.height)/2;
			
			// 戻るボタンを配置する
			_main.setBackBtnAction(this.backBtnHandler);
		}
		
		/**
		 * 写真の表示から戻る.
		 * @param evt クリックイベント
		 */
		public function backBtnHandler(evt:MouseEvent) {
			_main.getStage().removeChild(_imageLoader);
			_main.backBtnAction();
		}
		
		/**
		 * カメラロールをキャンセルした時の処理.
		 * @param evt クリックイベント
		 */
		public function cancelHandler(evt:Event) {
			_main.showButtons();
		}
	}
}