package jp.ameba.sp.app.controller
{
	import flash.display.*;
	import flash.events.*;
	import flash.filesystem.*;
	import flash.media.*;
	import flash.system.*;
	import flash.utils.*;
	import jp.ameba.sp.app.SampleMain;
	
	/**
	 * デバイスに搭載されたカメラを使って画像を取得するクラスです.
	 * 今回はカメラを通じた映像を取得して表示するところまでを実装しています.
	 */
	public class CameraViewController
	{
		/*カメラ機能.*/
		private var _myCamera:Camera;
		/*ビデオ(映像)インスタンス.*/
		var _myVideo:Video;
		/*メインクラス.*/
		private var _main:SampleMain;
		
		/**
		 * コンストラクタ.
		 */
		public function CameraViewController()
		{
			_main = SampleMain.getInstance();
		}
		/**
		 * デバイスカメラから画像を取得する準備をする.
		 */
		public function startUp() {
			_main.addLoading();
			
			// カメラクラスのインスタンスを作成
			_myCamera = Camera.getCamera();
			// 映像サイズ幅、映像サイズ高さ、フレームレートを設定
			_myCamera.setMode(_main.getStage().stageHeight/2, _main.getStage().stageWidth - SampleMain.MARGIN_LEFT*2, 30);
			// カメラの起動状態をチェックするイベントを設定
			_myCamera.addEventListener(StatusEvent.STATUS, statusHandler);
			// 映像を画面に表示する
			addVideo();
			
			// 戻るボタンの処理
			_main.setBackBtnAction(this.backBtnHandler);
		}
		
		/**
		 * 映像取得を終了する.
		 */
		public function disConnection() {
			_myVideo.clear();
			_main.getStage().removeChild(_myVideo);
			_main.backBtnAction();
		}
		/**
		 * 映像取得を終了する.
		 * (backボタン用)
		 */
		public function backBtnHandler(evt:MouseEvent) {
			disConnection();
		}
		
		/**
		 * Cameraクラスのステータスイベント処理.
		 * カメラが応答している間はカメラからの映像を画面に表示します.
		 */
		private function statusHandler(event:StatusEvent):void {
			// カメラの応答を確認する
			if (event.code != "Camera.Unmuted") {
				// カメラの応答が無ければ終了処理を行う.
				disConnection();
			}
		}
		
		/**
		 * カメラから取得した映像を画面に表示する.
		 */
		private function addVideo():void {
			_main.removeLoading();
			_myVideo = new Video(_myCamera.width, _myCamera.height);
			_myVideo.attachCamera(_myCamera);
			// なぜかVideoが横向きデフォルトになっているので回転させる
			_myVideo.rotation = 90;
			_myVideo.x = _main.getStage().stageWidth - SampleMain.MARGIN_LEFT;
			_myVideo.y = SampleMain.MARGIN_TOP;
			_main.getStage().addChild(_myVideo);
		}
	}
}