package jp.ameba.sp.app.controller
{
	import com.yahoo.maps.api.YahooMap;
	import com.yahoo.maps.api.YahooMapEvent;
	import com.yahoo.maps.api.core.location.Address;
	import com.yahoo.maps.api.core.location.LatLon;
	import com.yahoo.maps.webservices.geocoder.GeocoderResult;
	import com.yahoo.maps.webservices.geocoder.events.GeocoderEvent;
	
	import flash.display.*;
	import flash.events.*;
	import flash.net.*;
	import flash.sensors.*;
	import flash.text.*;
	import flash.utils.*;
	
	import jp.ameba.sp.app.SampleMain;
	
	
	/**
	 * GPS機能を操作するクラス.
	 * Yahoo!MapのFlash for iPhone向けのAPIを使ってアプリ内に地図を表示します.
	 * 起動すると中心を現在地に合わせて地図を表示します.
	 */
	public class GeoLocationController
	{
		/*メインクラス.*/
		var _main:SampleMain;
		/*位置情報クラス.*/
		var _myGeolocation:Geolocation;
		/*位置情報を表示するテキストフィールド.*/
		var latsText:TextField;
		/*緯度経度を持つクラス.*/
		var latlon:LatLon;
		/*Yahoo!Mapクラス*/
		var _map:YahooMap;
		var _address:Address;
		var appid:String = "eeeVtKPV34GqQxAzop1R2nXO3YHD5PFu7RwRZf.z.xb5s8ceEupI.7r4WVcBnCCd";
		
		/**
		 * コンストラクタ.
		 */
		public function GeoLocationController()
		{
			_main = SampleMain.getInstance();
		}
		/**
		 * GPS機能の準備をする.
		 */
		public function startUp() {
			// loadingをくっつける
			_main.addLoading();
			// 経度緯度を表示するテキストエリア
			latsText = new TextField();
			latsText.textColor=0x000000;
			latsText.autoSize = TextFieldAutoSize.LEFT;
			latsText.wordWrap = true;
			latsText.width = _main.getStage().stageWidth - SampleMain.MARGIN_LEFT*2;
			_main.getStage().addChild(latsText);
			latsText.text = "緯度経度を表示";
			latsText.x = SampleMain.MARGIN_LEFT;
			latsText.y = SampleMain.MARGIN_TOP;
			
			//地図の作成
			createMap();
		}
		
		/**
		 * Yahoo!Mapを作成する.
		 */
		function createMap() {
			// Yahoo!Mapクラスを作成
			_map = new YahooMap();
			// Yahoo!Mapの初期化イベントを設定
			_map.addEventListener(YahooMapEvent.MAP_INITIALIZE, onMapInitHandler);
			// Yahoo!MapID、幅、高さを設定します
			_map.init(appid, _main.getStage().stageWidth - SampleMain.MARGIN_LEFT*2, (_main.getStage().stageHeight)/2);
		}
		
		/**
		 * マップが初期化された後に呼び出される処理.
		 * 初期表示位置の設定を行う.
		 * @param evt マップの初期化が完了したイベント
		 */
		function onMapInitHandler(evt:YahooMapEvent) {
			_main.removeLoading();
			// 地図の操作パネルなどを追加
			_map.addPanControl();
			_map.addZoomWidget();
			_map.addTypeWidget();
			
			// 初期表示の位置を検索(英語表記の住所形式)
			_address = new Address("Chuo-ku, Tokyo, Japan");
			// 地図の検索に成功した場合のイベントを設定
			_address.addEventListener(GeocoderEvent.GEOCODER_SUCCESS, handleGeocodeSuccess);
			// 設定した住所で検索する
			_address.geocode();
			// Mapを画面に配置します。 
			_main.getStage().addChild(_map);
			_map.x = (_main.getStage().stageWidth - _map.width)/2;
			_map.y = SampleMain.MARGIN_TOP+latsText.height*2.5;
			
			_main.setBackBtnAction(backBtnHandler);
			
			// 地図の初期表示が終わったらGPS機能の初期化をする
			createGeoLocation();
		}
		
		/**
		 * マップの初期設定位置設定が完了した後に呼び出される処理.
		 * 検索結果に合わせて倍率を設定し、地図の中心点に設定する.
		 * @param event マップの位置特定が完了したイベント
		 */
		function handleGeocodeSuccess(event:GeocoderEvent):void
		{
			// 検索結果を取得
			var result:GeocoderResult = _address.geocoderResultSet.firstResult;
			// 検索結果の表示倍率に合わせる
			_map.zoomLevel = result.zoomLevel;
			// 地図の中心地点を検索結果に合わせる
			_map.centerLatLon = result.latlon;
		}
		/**
		 * GPS機能を起動する.
		 * 今回は1秒ごとに現在地を更新するように設定.
		 */
		function createGeoLocation() {
			_myGeolocation = new Geolocation();
			// 更新頻度を設定
			_myGeolocation.setRequestedUpdateInterval(1000);
			// 更新イベントを設定
			_myGeolocation.addEventListener(GeolocationEvent.UPDATE, geolocationHandler);
		}
		
		/**
		 * GPSの位置情報が更新された時に呼び出される処理.
		 * 更新された位置を中心にマップを移動する.
		 * @param evt 位置情報更新のイベント
		 */
		function geolocationHandler(evt:GeolocationEvent) {
			// 経度
			var long:Number = evt.longitude;
			// 緯度
			var lat:Number = evt.latitude;
			latsText.text = "経度:" + long +"\n" + "緯度:"+lat;
			// 地図の中心地を現在地に合わせる
			_map.centerLatLon = new LatLon(lat, long);
		}
		/**
		 * GPSセンサーを終了する.
		 */
		function endGPS() {
			_main.getStage().removeChild(latsText);
			_main.getStage().removeChild(_map);
			_myGeolocation.removeEventListener(GeolocationEvent.UPDATE, geolocationHandler);
			_main.backBtnAction();
		}
		/**
		 * GPSセンサーを終了する.
		 * (backボタン用)
		 */
		public function backBtnHandler(evt:MouseEvent) {
			endGPS();
		}
	}
}